@@ -457,6 +457,7 @@ SC_Constructor(ConnectionClass *conn)
 		rv->callbacks = NULL;
 		GetDataInfoInitialize(SC_get_GDTI(rv));
 		PutDataInfoInitialize(SC_get_PDTI(rv));
+		rv->lock_CC_for_rb = FALSE;
 		INIT_STMT_CS(rv);
 	}
 	return rv;
@@ -687,6 +688,11 @@ SC_initialize_stmts(StatementClass *self, BOOL initializeOriginal)
 	ProcessedStmt *pstmt;
 	ProcessedStmt *next_pstmt;
 
+	if (self->lock_CC_for_rb)
+	{
+		LEAVE_CONN_CS(SC_get_conn(self));
+		self->lock_CC_for_rb = FALSE;
+	}
 	if (initializeOriginal)
 	{
 		if (self->statement)
@@ -1422,6 +1428,8 @@ MYLOG(DETAIL_LOG_LEVEL, "entering %p->%p check=%i\n", from_res ,self, check);
 		    0 < self->__error_number)
 			return;
 	}
+	if (!from_res)
+		return;
 	self->__error_number = number;
 	if (!check || message)
 	{
@@ -1958,7 +1966,7 @@ SC_execute(StatementClass *self)
 		QueryInfo	*qryi = NULL;
 
 		qflag |= (SQL_CONCUR_READ_ONLY != self->options.scroll_concurrency ? CREATE_KEYSET : 0);
-		MYLOG(0, "       Sending SELECT statement on stmt=%p, cursor_name='%s' qflag=%d,%d\n", self, SC_cursor_name(self), qflag, self->options.scroll_concurrency);
+		MYLOG(0, "       Sending SELECT statement on stmt=%p, cursor_name='%s' qflag=%d," FORMAT_UINTEGER "\n", self, SC_cursor_name(self), qflag, self->options.scroll_concurrency);
 
 		/* send the declare/select */
 		if (useCursor)
@@ -2355,7 +2363,7 @@ SC_log_error(const char *func, const char *desc, const StatementClass *self)
 			QLOG(level, "                 stmt_with_params='%s'\n", NULLCHECK(self->stmt_with_params));
 			QLOG(level, "                 data_at_exec=%d, current_exec_param=%d, put_data=%d\n", self->data_at_exec, self->current_exec_param, self->put_data);
 			QLOG(level, "                 currTuple=" FORMAT_LEN ", current_col=%d, lobj_fd=%d\n", self->currTuple, self->current_col, self->lobj_fd);
-			QLOG(level, "                 maxRows=" FORMAT_LEN ", rowset_size=" FORMAT_LEN ", keyset_size=" FORMAT_LEN ", cursor_type=%u, scroll_concurrency=%d\n", self->options.maxRows, rowsetSize, self->options.keyset_size, self->options.cursor_type, self->options.scroll_concurrency);
+			QLOG(level, "                 maxRows=" FORMAT_LEN ", rowset_size=" FORMAT_LEN ", keyset_size=" FORMAT_LEN ", cursor_type=" FORMAT_UINTEGER ", scroll_concurrency=" FORMAT_UINTEGER "\n", self->options.maxRows, rowsetSize, self->options.keyset_size, self->options.cursor_type, self->options.scroll_concurrency);
 			QLOG(level, "                 cursor_name='%s'\n", SC_cursor_name(self));
 
 			QLOG(level, "                 ----------------QResult Info -------------------------------\n");
